glia package
============

Subpackages
-----------

.. toctree::

    glia.cli
    glia.widgets
    glia.windows

Submodules
----------

glia.app module
---------------

.. automodule:: glia.app
    :members:
    :undoc-members:
    :show-inheritance:

glia.definitions module
-----------------------

.. automodule:: glia.definitions
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: glia
    :members:
    :undoc-members:
    :show-inheritance:
